#!/usr/bin/env python3
#
# Requirements:
# pip install -U git+https://github.com/VimT/MaxMind-DB-Writer-python
#
from netaddr import IPSet
from mmdb_writer import MMDBWriter


bad_blocks = IPSet([
    # private network
    '10.0.0.0/8', '172.16.0.0/12', '192.168.0.0/16',
    # loopback
    '127.0.0.0/8',
    # local-link
    '169.254.0.0/16',
])

city_writer = MMDBWriter(ip_version=4, database_type='City', description='Runbot Fake City GeoIP')
country_writer = MMDBWriter(ip_version=4, database_type='Country', description='Runbot Fake Country GeoIP')
# for test_ping.py
city_writer.insert_network(
    IPSet(['217.194.208.0/20']),
    {
        'country': {'names': {'en': 'United Kingdom'}, 'iso_code': 'GB', 'is_in_european_union': False, 'geoname_id': 44},
        'city': {'names': {'en': 'London'}},
        'location': {'latitude': 51.506014, 'longitude': -0.1398098, 'time_zone': 'Europe/London'},
        'isp': 'Runbot Ping Test',
    }
)
country_writer.insert_network(
    IPSet(['217.194.208.0/20']),
    {
        'country': {'names': {'en': 'United Kingdom'}, 'iso_code': 'GB', 'is_in_european_union': False, 'geoname_id': 44},
        'isp': 'Runbot Ping Test',
    }
)
# default, fallback to Farm 2
city_writer.insert_network(
    IPSet(['%d.0.0.0/8' % i for i in range(255)]) - IPSet(['217.194.208.0/20']) - bad_blocks,
    {
        'country': {'names': {'en': 'Belgium'}, 'iso_code': 'BE', 'is_in_european_union': True, 'geoname_id': 32},
        'city': {'names': {'en': 'Grand-Rosière'}},
        'location': {'latitude': 50.6300005, 'longitude': 4.8611832, 'time_zone': 'Europe/Brussels'},
        'isp': 'Runbot',
    },
)

country_writer.insert_network(
    IPSet(['%d.0.0.0/8' % i for i in range(255)]) - IPSet(['217.194.208.0/20']) - bad_blocks,
    {
        'country': {'names': {'en': 'Belgium'}, 'iso_code': 'BE', 'is_in_european_union': True, 'geoname_id': 32},
        'isp': 'Runbot',
    },
)

city_writer.to_db_file('runbot-city.mmdb')
country_writer.to_db_file('runbot-country.mmdb')
